@@ -22,7 +22,10 @@
 #
 ########################################################################################################################
 
-"""Advanced example technology module"""
+"""Advanced example technology module.
+
+WARNING: This technology module is outdated. Use laygo2_tech_quick_start instead.
+"""
 
 import yaml
 import os
@@ -30,13 +33,13 @@ import os
 # Technology parameters
 # should be tech_param_path = "laygo2_tech/laygo2_tech.yaml" for actual use
 tech_param_path = "laygo2/examples/laygo2_tech/laygo2_tech.yaml"
-'''
+"""
 path = os.path.abspath(__file__)
 dir_path = os.path.dirname(path)
 tech_param_path = dir_path+"/laygo2_tech.yaml"
-'''
+"""
 
-with open(tech_param_path, 'r') as stream:
+with open(tech_param_path, "r") as stream:
     try:
         tech_params = yaml.safe_load(stream)
     except yaml.YAMLError as exc:
